# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.report
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_report_control_model import XReportControlModel as XReportControlModel_2d800f4a
if typing.TYPE_CHECKING:
    from ..drawing.line_dash import LineDash as LineDash_a54e0afc
    from ..util.color import Color as Color_68e908c5
    from com.sun.star.drawing.LineStyle import LineStyleProto

class XFixedLine(XReportControlModel_2d800f4a):
    """

    See Also:
        `API XFixedLine <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1report_1_1XFixedLine.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.report'
    __ooo_full_ns__: str = 'com.sun.star.report.XFixedLine'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.report.XFixedLine'

    @abstractproperty
    def LineColor(self) -> Color_68e908c5:
        """
        This property contains the line color.
        """
        ...

    @abstractproperty
    def LineDash(self) -> LineDash_a54e0afc:
        """
        This property contains the dash of the line.
        """
        ...

    @abstractproperty
    def LineStyle(self) -> LineStyleProto:
        """
        This property contains the type of the line.
        """
        ...

    @abstractproperty
    def LineTransparence(self) -> int:
        """
        This property contains the extent of transparency.
        """
        ...

    @abstractproperty
    def LineWidth(self) -> int:
        """
        This property contains the width of the line in 1/100th mm.
        """
        ...

    @abstractproperty
    def Orientation(self) -> int:
        """
        specifies the orientation of the control.
        """
        ...


__all__ = ['XFixedLine']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from .render_state import RenderState as RenderState_e4490d27
    from .view_state import ViewState as ViewState_cab30c62
    from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20

class XSprite(XInterface_8f010a43):
    """
    Interface to control a sprite object.
    
    This is the basic interface to control a sprite object on a XSpriteCanvas. Sprites are moving, back-buffered objects.

    See Also:
        `API XSprite <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XSprite.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XSprite'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XSprite'

    @abstractmethod
    def clip(self, aClip: XPolyPolygon2D_e1b0e20) -> None:
        """
        Apply a clipping to the shape output.
        
        The given clip poly-polygon is always interpreted in device coordinate space. As the sprite has its own local coordinate system, with its origin on screen being equal to its current position, the clip poly-polygon's origin will always coincide with the sprite's origin. Furthermore, if any sprite transformation is set via transform(), the clip is subject to this transformation, too. The implementation is free, if it has a cached representation of the sprite at hand, to clip-output only this cached representation (e.g. a bitmap), instead of re-rendering the sprite from first principles. This is usually the case for an implementation of a XCustomSprite interface, since it typically has no other cached pictorial information at hand.
        
        Please note that if this sprite is not animated, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().
        
        Specifying an empty interface denotes no clipping, i.e. everything contained in the sprite will be visible (subject to device-dependent constraints, of course). Specifying an empty XPolyPolygon2D, i.e. a poly-polygon containing zero polygons, or an XPolyPolygon2D with any number of empty sub-polygons, denotes the NULL clip. That means, nothing from the sprite will be visible.
        """
        ...
    @abstractmethod
    def hide(self) -> None:
        """
        Make the sprite invisible.
        
        This method makes the sprite invisible.
        """
        ...
    @abstractmethod
    def move(self, aNewPos: RealPoint2D_d6e70c78, aViewState: ViewState_cab30c62, aRenderState: RenderState_e4490d27) -> None:
        """
        Move sprite to the specified position.
        
        The position specified here is first transformed by the combined view and render transformation. The resulting position is then used as the output position (also in device coordinates) of the rendered sprite content.
        
        Please note that if this sprite is not animated, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setAlpha(self, nAlpha: float) -> None:
        """
        Set overall transparency of the sprite.
        
        This method is useful for e.g. fading in/out of animations.
        
        Please note that if this sprite is not animated, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def setPriority(self, nPriority: float) -> None:
        """
        Set sprite priority.
        
        The sprite priority determines the order of rendering relative to all other sprites of the associated canvas. The higher the priority, the later will the sprite be rendered, or, in other words, the closer to the screen surface the sprite is shown.
        """
        ...
    @abstractmethod
    def show(self) -> None:
        """
        Make the sprite visible.
        
        This method makes the sprite visible on the canvas it was created on.
        """
        ...
    @abstractmethod
    def transform(self, aTransformation: AffineMatrix2D_ff040da8) -> None:
        """
        Apply a local transformation to the sprite.
        
        The given transformation matrix locally transforms the sprite shape. If this transformation contains translational components, be aware that sprite content moved beyond the sprite area (a box from (0,0) to (spriteWidth,spriteHeight)) might (but need not) be clipped. Use XSprite.move() to change the sprite location on screen. The canvas implementations are free, if they have a cached representation of the sprite at hand, to transform only this cached representation (e.g. a bitmap), instead of re-rendering the sprite from first principles. This is usually the case for an implementation of a XCustomSprite interface, since it typically has no other cached pictorial information at hand.
        
        Please note that if this sprite is not animated, the associated XSpriteCanvas does not update changed sprites automatically, but has to be told to do so via XSpriteCanvas.updateScreen().

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XSprite']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from abc import abstractmethod
from .x_schema_supplier import XSchemaSupplier as XSchemaSupplier_eca11373

class XVersionedSchemaSupplier(XSchemaSupplier_eca11373):
    """
    provides access to versioned configuration component schemas.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XVersionedSchemaSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XVersionedSchemaSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XVersionedSchemaSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XVersionedSchemaSupplier'

    @abstractmethod
    def getSchemaVersion(self, aComponent: str) -> str:
        """
        Returns the schema version for a particular component.
        
        The format of the version string is arbitrary. No meaning should be attached to it, unless an implementing service defines one. If no version can be determined, an empty string may be returned.
        
        Clients may assume that all instances of a schema with the same version are identical. The converse is not true. In particular an implementation may return the same version string for all schemas it supplies (i.e. return a version for the complete schema, including all components)

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XVersionedSchemaSupplier']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from .text_portion import TextPortion as TextPortion_a6f80b5d
if typing.TYPE_CHECKING:
    from ..beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from .x_text import XText as XText_690408ca
    from ..util.date_time import DateTime as DateTime_84de09d3

class RedlinePortion(TextPortion_a6f80b5d):
    """
    Service Class

    A RedlinePortion is a TextPortion that marks a change that has been recorded by the change tracking.

    See Also:
        `API RedlinePortion <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1RedlinePortion.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.RedlinePortion'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsInHeaderFooter(self) -> bool:
        """
        determines whether the portion is member of a header or footer text.
        """
        ...

    @abstractproperty
    def MergeLastPara(self) -> bool:
        """
        determines whether the last paragraph of a redline text has to be merged with a possible following text content (i.e.
        
        a text table)
        """
        ...

    @abstractproperty
    def RedlineAuthor(self) -> str:
        """
        contains the name of the author of the change.
        """
        ...

    @abstractproperty
    def RedlineComment(self) -> str:
        """
        contains a comment for the change.
        """
        ...

    @abstractproperty
    def RedlineDateTime(self) -> DateTime_84de09d3:
        """
        contains the date and time of the change.
        """
        ...

    @abstractproperty
    def RedlineIdentifier(self) -> str:
        """
        contains a unique identifier for the redline.
        
        This is necessary for file export filters to able to recognize redline portions that point to the same redline.
        """
        ...

    @abstractproperty
    def RedlineSuccessorData(self) -> PropertyValues_d6470ce6:
        """
        contains the data of a second level redline data
        
        The elements of the sequence are:
        """
        ...

    @abstractproperty
    def RedlineText(self) -> XText_690408ca:
        """
        provides access to the text of the redline.
        
        This interface is only provided if the change is not visible. The visibility depends on the redline display options that are set at the documents property set (RedlineDisplayType).
        """
        ...

    @abstractproperty
    def RedlineType(self) -> str:
        """
        contains the type of the change
        
        Valid type names are:
        """
        ...


__all__ = ['RedlinePortion']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .context_information import ContextInformation as ContextInformation_1ece0f08

class XDebugging(XInterface_8f010a43):
    """
    makes it possible to set breakpoints in an interpreter.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XDebugging <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XDebugging.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XDebugging'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XDebugging'

    @abstractmethod
    def clearAllBreakPoints(self, aModuleName: str) -> None:
        """
        clears all breakpoints in the module set by \"setBreakPoint\".
        """
        ...
    @abstractmethod
    def doContinue(self) -> None:
        """
        continues the program execution.
        """
        ...
    @abstractmethod
    def dumpVariable(self, aVariableName: str, nCallStackPos: int) -> str:
        """
        returns the value of the variable at the given stack position.
        """
        ...
    @abstractmethod
    def eval(self, aSourceCode: str, nCallStackPos: int) -> str:
        """
        Evaluates an expression.
        """
        ...
    @abstractmethod
    def getContextInformation(self, nCallStackPos: int) -> ContextInformation_1ece0f08:
        """
        returns more detailed information about a specified stack frame.
        """
        ...
    @abstractmethod
    def getStackTrace(self) -> typing.Tuple[str, ...]:
        """
        Returns the engine's stack trace of the current execute position.
        
        Line break is the delimiter.
        """
        ...
    @abstractmethod
    def isVariable(self, aVariableName: str, nCallStackPos: int) -> bool:
        """
        returns whether the given variable exists within the specified stack frame.
        """
        ...
    @abstractmethod
    def setBreakPoint(self, aModuleName: str, nSourceCodeLine: int, bOn: bool) -> int:
        """
        returns the source code line where the breakpoint was set.
        """
        ...
    @abstractmethod
    def setVariable(self, aVariableName: str, aValue: str, nCallStackPos: int) -> None:
        """
        sets the value of the specified variable within the specified stack frame.
        """
        ...
    @abstractmethod
    def stepIn(self) -> None:
        """
        executes the next and only the next statement.
        
        If the next statement is a function call, only the function entered.
        """
        ...
    @abstractmethod
    def stepOut(self) -> None:
        """
        executes the program until the next return from this stack frame.
        """
        ...
    @abstractmethod
    def stepOver(self) -> None:
        """
        executes the next and only the next statement.
        
        If the next statement is a function call, the function is executed completely.
        """
        ...
    @abstractmethod
    def stop(self) -> None:
        """
        stops the execution of the interpreter.
        
        To continue with the execution, call XDebugging.doContinue().
        """
        ...

__all__ = ['XDebugging']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class CharSet(metaclass=UnoConstMeta, type_name="com.sun.star.awt.CharSet", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.CharSet``"""
        pass

    class CharSetEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.CharSet", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.CharSet`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import CharSet as CharSet
    else:
        # keep document generators happy
        from ...lo.awt.char_set import CharSet as CharSet

    class CharSetEnum(IntEnum):
        """
        Enum of Const Class CharSet

        These values are used to specify the characters which are available in a font and their codes.
        
        The currently defined constants of CharSet have the same numerical values as the corresponding enum values of the C/C++ rtl_TextEncoding (from rtl/textenc.h). This correspondence is by design. Since CharSet is deprecated, however, it is not planned to add further constants to keep it in sync with rtl_TextEncoding.
        
        .. deprecated::
        
            Class is deprecated.
        """
        DONTKNOW = CharSet.DONTKNOW
        """
        specifies an unknown character set.
        """
        ANSI = CharSet.ANSI
        """
        specifies the ANSI character set.
        """
        MAC = CharSet.MAC
        """
        specifies the Apple Macintosh character set.
        """
        IBMPC_437 = CharSet.IBMPC_437
        """
        specifies the IBM PC character set number 437.
        """
        IBMPC_850 = CharSet.IBMPC_850
        """
        specifies the IBM PC character set number 850.
        """
        IBMPC_860 = CharSet.IBMPC_860
        """
        specifies the IBM PC character set number 860.
        """
        IBMPC_861 = CharSet.IBMPC_861
        """
        specifies the IBM PC character set number 861.
        """
        IBMPC_863 = CharSet.IBMPC_863
        """
        specifies the IBM PC character set number 863.
        """
        IBMPC_865 = CharSet.IBMPC_865
        """
        specifies the IBM PC character set number 865.
        """
        SYSTEM = CharSet.SYSTEM
        """
        specifies the system character set.
        """
        SYMBOL = CharSet.SYMBOL
        """
        specifies a set of symbols.
        """

__all__ = ['CharSet', 'CharSetEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from com.sun.star.drawing.MeasureKind import MeasureKindProto
    from com.sun.star.drawing.MeasureTextHorzPos import MeasureTextHorzPosProto
    from com.sun.star.drawing.MeasureTextVertPos import MeasureTextVertPosProto

class MeasureProperties(ABC):
    """
    Service Class

    This service describes a MeasureShape.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API MeasureProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1MeasureProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.MeasureProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def MeasureBelowReferenceEdge(self) -> bool:
        """
        If this property is TRUE, the measure is drawn below the reference edge instead of above it.
        """
        ...

    @abstractproperty
    def MeasureDecimalPlaces(self) -> int:
        """
        This value is the number of decimal places that is used to format the measure value.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def MeasureHelpLine1Length(self) -> int:
        """
        This is the length of the first help line.
        """
        ...

    @abstractproperty
    def MeasureHelpLine2Length(self) -> int:
        """
        This is the length of the second help line.
        """
        ...

    @abstractproperty
    def MeasureHelpLineDistance(self) -> int:
        """
        This is the distance from the measure line to the start of the help lines.
        """
        ...

    @abstractproperty
    def MeasureHelpLineOverhang(self) -> int:
        """
        This is the overhang of the two help lines.
        """
        ...

    @abstractproperty
    def MeasureKind(self) -> MeasureKindProto:
        """
        This enumeration specifies the MeasureKind.
        """
        ...

    @abstractproperty
    def MeasureLineDistance(self) -> int:
        """
        This is the distance from the reference edge to the measure line.
        """
        ...

    @abstractproperty
    def MeasureOverhang(self) -> int:
        """
        This is the overhang of the reference line over the help lines.
        """
        ...

    @abstractproperty
    def MeasureShowUnit(self) -> bool:
        """
        If this is TRUE, the unit of measure is shown in the measure text.
        """
        ...

    @abstractproperty
    def MeasureTextAutoAngle(self) -> bool:
        """
        If this is TRUE, the angle of the measure is set automatically.
        """
        ...

    @abstractproperty
    def MeasureTextAutoAngleView(self) -> int:
        """
        This is the automatic angle.
        """
        ...

    @abstractproperty
    def MeasureTextFixedAngle(self) -> int:
        """
        This is the fixed angle.
        """
        ...

    @abstractproperty
    def MeasureTextHorizontalPosition(self) -> MeasureTextHorzPosProto:
        """
        This is the horizontal position of the measure text.
        """
        ...

    @abstractproperty
    def MeasureTextIsFixedAngle(self) -> bool:
        """
        If this value is TRUE, the measure has a fixed angle.
        """
        ...

    @abstractproperty
    def MeasureTextRotate90(self) -> bool:
        """
        If this value is TRUE, the text is rotated 90 degrees.
        """
        ...

    @abstractproperty
    def MeasureTextUpsideDown(self) -> bool:
        """
        If this value is TRUE, the text is printed upside down.
        """
        ...

    @abstractproperty
    def MeasureTextVerticalPosition(self) -> MeasureTextVertPosProto:
        """
        This is the vertical position of the text.
        """
        ...


__all__ = ['MeasureProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class EnhancedCustomShapeSegment(object):
    """
    Struct Class


    See Also:
        `API EnhancedCustomShapeSegment <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegment.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.EnhancedCustomShapeSegment'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.EnhancedCustomShapeSegment'
    """Literal Constant ``com.sun.star.drawing.EnhancedCustomShapeSegment``"""

    def __init__(self, Command: typing.Optional[int] = 0, Count: typing.Optional[int] = 0) -> None:
        """
        Constructor

        Arguments:
            Command (int, optional): Command value.
            Count (int, optional): Count value.
        """
        super().__init__()

        if isinstance(Command, EnhancedCustomShapeSegment):
            oth: EnhancedCustomShapeSegment = Command
            self.Command = oth.Command
            self.Count = oth.Count
            return

        kargs = {
            "Command": Command,
            "Count": Count,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._command = kwargs["Command"]
        self._count = kwargs["Count"]


    @property
    def Command(self) -> int:
        return self._command

    @Command.setter
    def Command(self, value: int) -> None:
        self._command = value

    @property
    def Count(self) -> int:
        return self._count

    @Count.setter
    def Count(self, value: int) -> None:
        self._count = value


__all__ = ['EnhancedCustomShapeSegment']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FormComponentType(metaclass=UnoConstMeta, type_name="com.sun.star.form.FormComponentType", name_space="com.sun.star.form"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.form.FormComponentType``"""
        pass

    class FormComponentTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.form.FormComponentType", name_space="com.sun.star.form"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.form.FormComponentType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.form import FormComponentType as FormComponentType
    else:
        # keep document generators happy
        from ...lo.form.form_component_type import FormComponentType as FormComponentType

    class FormComponentTypeEnum(IntEnum):
        """
        Enum of Const Class FormComponentType

        These constants specify the class types used to identify a component.
        """
        CONTROL = FormComponentType.CONTROL
        """
        This generic identifier is for controls which cannot be identified by another specific identifier.
        """
        COMMANDBUTTON = FormComponentType.COMMANDBUTTON
        """
        specifies a control that is used to begin, interrupt, or end a process.
        """
        RADIOBUTTON = FormComponentType.RADIOBUTTON
        """
        specifies a control that acts like a radio button.
        
        Grouped together, such radio buttons present a set of two or more mutually exclusive choices to the user.
        """
        IMAGEBUTTON = FormComponentType.IMAGEBUTTON
        """
        specifies a control that displays an image that responds to mouse clicks.
        """
        CHECKBOX = FormComponentType.CHECKBOX
        """
        specifies a control that is used to check or uncheck to turn an option on or off.
        """
        LISTBOX = FormComponentType.LISTBOX
        """
        specifies a control that displays a list from which the user can select one or more items.
        """
        COMBOBOX = FormComponentType.COMBOBOX
        """
        specifies a control that is used when a list box combined with a static text control or an edit control is needed.
        """
        GROUPBOX = FormComponentType.GROUPBOX
        """
        specifies a control that displays a frame around a group of controls with or without a caption.
        """
        TEXTFIELD = FormComponentType.TEXTFIELD
        """
        specifies a control that is a text component that allows for the editing of a single line of text.
        """
        FIXEDTEXT = FormComponentType.FIXEDTEXT
        """
        specifies a control to display a fixed text, usually used to label other controls.
        """
        GRIDCONTROL = FormComponentType.GRIDCONTROL
        """
        is a table like control to display database data.
        """
        FILECONTROL = FormComponentType.FILECONTROL
        """
        specifies a control which can be used to enter text, extended by an (user-startable) file dialog to browse for files.
        """
        HIDDENCONTROL = FormComponentType.HIDDENCONTROL
        """
        specifies a control that should not be visible.
        """
        IMAGECONTROL = FormComponentType.IMAGECONTROL
        """
        specifies a control to display an image.
        """
        DATEFIELD = FormComponentType.DATEFIELD
        """
        specifies a control to display and edit a date value.
        """
        TIMEFIELD = FormComponentType.TIMEFIELD
        """
        specifies a control to display and edit a time value.
        """
        NUMERICFIELD = FormComponentType.NUMERICFIELD
        """
        specifies a field to display and edit a numeric value.
        """
        CURRENCYFIELD = FormComponentType.CURRENCYFIELD
        """
        specifies a field to display and edit a currency value.
        """
        PATTERNFIELD = FormComponentType.PATTERNFIELD
        """
        specifies a control to display and edit a string according to a pattern.
        """
        SCROLLBAR = FormComponentType.SCROLLBAR
        """
        specifies a control to display and edit, in the form of a scrollbar, a value from a continuous value range
        """
        SPINBUTTON = FormComponentType.SPINBUTTON
        """
        specifies a control to edit, in the form of a spin field, a value from a continuous range of values
        """
        NAVIGATIONBAR = FormComponentType.NAVIGATIONBAR
        """
        specifies a control which provides controller functionality for the com.sun.star.form.component.DataForm it belongs to, such as functionality to navigate or filter this form.
        """

__all__ = ['FormComponentType', 'FormComponentTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FontEmphasisMark(metaclass=UnoConstMeta, type_name="com.sun.star.awt.FontEmphasisMark", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.FontEmphasisMark``"""
        pass

    class FontEmphasisMarkEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.FontEmphasisMark", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.FontEmphasisMark`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import FontEmphasisMark as FontEmphasisMark
    else:
        # keep document generators happy
        from ...lo.awt.font_emphasis_mark import FontEmphasisMark as FontEmphasisMark

    class FontEmphasisMarkEnum(IntEnum):
        """
        Enum of Const Class FontEmphasisMark

        These values are used to specify the kind of emphasis mark.
        
        They may be expanded in future versions.
        """
        NONE = FontEmphasisMark.NONE
        """
        specifies no emphasis mark.
        """
        DOT = FontEmphasisMark.DOT
        """
        specifies emphasis mark dot.
        """
        CIRCLE = FontEmphasisMark.CIRCLE
        """
        specifies emphasis mark circle.
        """
        DISC = FontEmphasisMark.DISC
        """
        specifies emphasis mark disc.
        """
        ACCENT = FontEmphasisMark.ACCENT
        """
        specifies emphasis mark accent.
        """
        ABOVE = FontEmphasisMark.ABOVE
        """
        specifies that the emphasis mark should be positioned above the characters.
        """
        BELOW = FontEmphasisMark.BELOW
        """
        specifies that the emphasis mark should be positioned below the characters.
        """

__all__ = ['FontEmphasisMark', 'FontEmphasisMarkEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.security
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.security.CertificateKind import CertificateKindProto

class CertificateKind(Enum):
    """
    Enum Class


    See Also:
        `API CertificateKind <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1security.html#a15fb2a8475364a68c176c7789e3611cc>`_
    """
    __ooo_ns__: str = 'com.sun.star.security'
    __ooo_full_ns__: str = 'com.sun.star.security.CertificateKind'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.security.CertificateKind'

    NONE = cast("CertificateKindProto", 'NONE')
    """
    No format specified.
    """
    OPENPGP = cast("CertificateKindProto", 'OPENPGP')
    """
    OpenPGP format of a certificate.
    """
    X509 = cast("CertificateKindProto", 'X509')
    """
    X.509 format of a certificate.
    """

__all__ = ['CertificateKind']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml
from __future__ import annotations
from ..document.export_filter import ExportFilter as ExportFilter_e5320d4f

class XMLExportFilter(ExportFilter_e5320d4f):
    """
    Service Class

    describes an export filter for XML-based file formats.
    
    It is an extension of com.sun.star.document.ExportFilter and differs from it only in that an com.sun.star.xml.sax.XDocumentHandler needs to be passed through the XInitialization interface. This XDocumentHandler will then be used to export the XML data stream.

    See Also:
        `API XMLExportFilter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1xml_1_1XMLExportFilter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml'
    __ooo_full_ns__: str = 'com.sun.star.xml.XMLExportFilter'
    __ooo_type_name__: str = 'service'


__all__ = ['XMLExportFilter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class FadeEffect(metaclass=UnoEnumMeta, type_name="com.sun.star.presentation.FadeEffect", name_space="com.sun.star.presentation"):
        """Dynamically created class that represents ``com.sun.star.presentation.FadeEffect`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.presentation.FadeEffect import CLOCKWISE as FADE_EFFECT_CLOCKWISE
        from com.sun.star.presentation.FadeEffect import CLOSE_HORIZONTAL as FADE_EFFECT_CLOSE_HORIZONTAL
        from com.sun.star.presentation.FadeEffect import CLOSE_VERTICAL as FADE_EFFECT_CLOSE_VERTICAL
        from com.sun.star.presentation.FadeEffect import COUNTERCLOCKWISE as FADE_EFFECT_COUNTERCLOCKWISE
        from com.sun.star.presentation.FadeEffect import DISSOLVE as FADE_EFFECT_DISSOLVE
        from com.sun.star.presentation.FadeEffect import FADE_FROM_BOTTOM as FADE_EFFECT_FADE_FROM_BOTTOM
        from com.sun.star.presentation.FadeEffect import FADE_FROM_CENTER as FADE_EFFECT_FADE_FROM_CENTER
        from com.sun.star.presentation.FadeEffect import FADE_FROM_LEFT as FADE_EFFECT_FADE_FROM_LEFT
        from com.sun.star.presentation.FadeEffect import FADE_FROM_LOWERLEFT as FADE_EFFECT_FADE_FROM_LOWERLEFT
        from com.sun.star.presentation.FadeEffect import FADE_FROM_LOWERRIGHT as FADE_EFFECT_FADE_FROM_LOWERRIGHT
        from com.sun.star.presentation.FadeEffect import FADE_FROM_RIGHT as FADE_EFFECT_FADE_FROM_RIGHT
        from com.sun.star.presentation.FadeEffect import FADE_FROM_TOP as FADE_EFFECT_FADE_FROM_TOP
        from com.sun.star.presentation.FadeEffect import FADE_FROM_UPPERLEFT as FADE_EFFECT_FADE_FROM_UPPERLEFT
        from com.sun.star.presentation.FadeEffect import FADE_FROM_UPPERRIGHT as FADE_EFFECT_FADE_FROM_UPPERRIGHT
        from com.sun.star.presentation.FadeEffect import FADE_TO_CENTER as FADE_EFFECT_FADE_TO_CENTER
        from com.sun.star.presentation.FadeEffect import HORIZONTAL_CHECKERBOARD as FADE_EFFECT_HORIZONTAL_CHECKERBOARD
        from com.sun.star.presentation.FadeEffect import HORIZONTAL_LINES as FADE_EFFECT_HORIZONTAL_LINES
        from com.sun.star.presentation.FadeEffect import HORIZONTAL_STRIPES as FADE_EFFECT_HORIZONTAL_STRIPES
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_BOTTOM as FADE_EFFECT_MOVE_FROM_BOTTOM
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_LEFT as FADE_EFFECT_MOVE_FROM_LEFT
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_LOWERLEFT as FADE_EFFECT_MOVE_FROM_LOWERLEFT
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_LOWERRIGHT as FADE_EFFECT_MOVE_FROM_LOWERRIGHT
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_RIGHT as FADE_EFFECT_MOVE_FROM_RIGHT
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_TOP as FADE_EFFECT_MOVE_FROM_TOP
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_UPPERLEFT as FADE_EFFECT_MOVE_FROM_UPPERLEFT
        from com.sun.star.presentation.FadeEffect import MOVE_FROM_UPPERRIGHT as FADE_EFFECT_MOVE_FROM_UPPERRIGHT
        from com.sun.star.presentation.FadeEffect import NONE as FADE_EFFECT_NONE
        from com.sun.star.presentation.FadeEffect import OPEN_HORIZONTAL as FADE_EFFECT_OPEN_HORIZONTAL
        from com.sun.star.presentation.FadeEffect import OPEN_VERTICAL as FADE_EFFECT_OPEN_VERTICAL
        from com.sun.star.presentation.FadeEffect import RANDOM as FADE_EFFECT_RANDOM
        from com.sun.star.presentation.FadeEffect import ROLL_FROM_BOTTOM as FADE_EFFECT_ROLL_FROM_BOTTOM
        from com.sun.star.presentation.FadeEffect import ROLL_FROM_LEFT as FADE_EFFECT_ROLL_FROM_LEFT
        from com.sun.star.presentation.FadeEffect import ROLL_FROM_RIGHT as FADE_EFFECT_ROLL_FROM_RIGHT
        from com.sun.star.presentation.FadeEffect import ROLL_FROM_TOP as FADE_EFFECT_ROLL_FROM_TOP
        from com.sun.star.presentation.FadeEffect import SPIRALIN_LEFT as FADE_EFFECT_SPIRALIN_LEFT
        from com.sun.star.presentation.FadeEffect import SPIRALIN_RIGHT as FADE_EFFECT_SPIRALIN_RIGHT
        from com.sun.star.presentation.FadeEffect import SPIRALOUT_LEFT as FADE_EFFECT_SPIRALOUT_LEFT
        from com.sun.star.presentation.FadeEffect import SPIRALOUT_RIGHT as FADE_EFFECT_SPIRALOUT_RIGHT
        from com.sun.star.presentation.FadeEffect import STRETCH_FROM_BOTTOM as FADE_EFFECT_STRETCH_FROM_BOTTOM
        from com.sun.star.presentation.FadeEffect import STRETCH_FROM_LEFT as FADE_EFFECT_STRETCH_FROM_LEFT
        from com.sun.star.presentation.FadeEffect import STRETCH_FROM_RIGHT as FADE_EFFECT_STRETCH_FROM_RIGHT
        from com.sun.star.presentation.FadeEffect import STRETCH_FROM_TOP as FADE_EFFECT_STRETCH_FROM_TOP
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_BOTTOM as FADE_EFFECT_UNCOVER_TO_BOTTOM
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_LEFT as FADE_EFFECT_UNCOVER_TO_LEFT
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_LOWERLEFT as FADE_EFFECT_UNCOVER_TO_LOWERLEFT
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_LOWERRIGHT as FADE_EFFECT_UNCOVER_TO_LOWERRIGHT
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_RIGHT as FADE_EFFECT_UNCOVER_TO_RIGHT
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_TOP as FADE_EFFECT_UNCOVER_TO_TOP
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_UPPERLEFT as FADE_EFFECT_UNCOVER_TO_UPPERLEFT
        from com.sun.star.presentation.FadeEffect import UNCOVER_TO_UPPERRIGHT as FADE_EFFECT_UNCOVER_TO_UPPERRIGHT
        from com.sun.star.presentation.FadeEffect import VERTICAL_CHECKERBOARD as FADE_EFFECT_VERTICAL_CHECKERBOARD
        from com.sun.star.presentation.FadeEffect import VERTICAL_LINES as FADE_EFFECT_VERTICAL_LINES
        from com.sun.star.presentation.FadeEffect import VERTICAL_STRIPES as FADE_EFFECT_VERTICAL_STRIPES
        from com.sun.star.presentation.FadeEffect import WAVYLINE_FROM_BOTTOM as FADE_EFFECT_WAVYLINE_FROM_BOTTOM
        from com.sun.star.presentation.FadeEffect import WAVYLINE_FROM_LEFT as FADE_EFFECT_WAVYLINE_FROM_LEFT
        from com.sun.star.presentation.FadeEffect import WAVYLINE_FROM_RIGHT as FADE_EFFECT_WAVYLINE_FROM_RIGHT
        from com.sun.star.presentation.FadeEffect import WAVYLINE_FROM_TOP as FADE_EFFECT_WAVYLINE_FROM_TOP

        class FadeEffect(uno.Enum):
            """
            Enum Class


            See Also:
                `API FadeEffect <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a9db0b8c5e72e0ae290ff76da0dd53e3d>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.presentation.FadeEffect', value)

            __ooo_ns__: str = 'com.sun.star.presentation'
            __ooo_full_ns__: str = 'com.sun.star.presentation.FadeEffect'
            __ooo_type_name__: str = 'enum'

            CLOCKWISE = FADE_EFFECT_CLOCKWISE
            """
            use the animation effect \"Clockwise\".

            use the fade effect \"Clockwise\".
            """
            CLOSE_HORIZONTAL = FADE_EFFECT_CLOSE_HORIZONTAL
            """
            use the animation effect \"Close Horizontal\".

            use the fade effect \"Close Horizontal\".
            """
            CLOSE_VERTICAL = FADE_EFFECT_CLOSE_VERTICAL
            """
            use the animation effect \"Close Vertical\".

            use the fade effect \"Close Vertical\".
            """
            COUNTERCLOCKWISE = FADE_EFFECT_COUNTERCLOCKWISE
            """
            use the animation effect \"Counter Clockwise\".

            use the fade effect \"Counter Clockwise\".
            """
            DISSOLVE = FADE_EFFECT_DISSOLVE
            """
            use the animation effect \"Spiral Inward Left\".

            use the fade effect \"Dissolve\".
            """
            FADE_FROM_BOTTOM = FADE_EFFECT_FADE_FROM_BOTTOM
            """
            use the animation effect \"Fade from Bottom\".

            use the fade effect \"Fade from Bottom\".
            """
            FADE_FROM_CENTER = FADE_EFFECT_FADE_FROM_CENTER
            """
            use the animation effect \"Fade from Center\".

            use the fade effect \"Fade from Center\".
            """
            FADE_FROM_LEFT = FADE_EFFECT_FADE_FROM_LEFT
            """
            use the animation effect \"Fade from Left\".

            use the fade effect \"Fade from Left\".
            """
            FADE_FROM_LOWERLEFT = FADE_EFFECT_FADE_FROM_LOWERLEFT
            """
            use the animation effect \"Fade from Lower Left\".

            use the fade effect \"Fade from Lower Left\".
            """
            FADE_FROM_LOWERRIGHT = FADE_EFFECT_FADE_FROM_LOWERRIGHT
            """
            use the animation effect \"Fade from Lower Right\".

            use the fade effect \"Fade from Lower Right\".
            """
            FADE_FROM_RIGHT = FADE_EFFECT_FADE_FROM_RIGHT
            """
            use the animation effect \"Fade from Right\".

            use the fade effect \"Fade from Right\".
            """
            FADE_FROM_TOP = FADE_EFFECT_FADE_FROM_TOP
            """
            use the animation effect \"Fade from Top\".

            use the fade effect \"Fade from Top\".
            """
            FADE_FROM_UPPERLEFT = FADE_EFFECT_FADE_FROM_UPPERLEFT
            """
            use the animation effect \"Fade from Upper Left\".

            use the fade effect \"Fade from Upper Left\".
            """
            FADE_FROM_UPPERRIGHT = FADE_EFFECT_FADE_FROM_UPPERRIGHT
            """
            use the animation effect \"Fade from Upper Right\".

            use the fade effect \"Fade from Upper Right\".
            """
            FADE_TO_CENTER = FADE_EFFECT_FADE_TO_CENTER
            """
            use the animation effect \"Fade to Center\".

            use the fade effect \"Fade to Center\".
            """
            HORIZONTAL_CHECKERBOARD = FADE_EFFECT_HORIZONTAL_CHECKERBOARD
            """
            use the animation effect \"Horizontal Checkerboard\".

            use the fade effect \"Horizontal Checkerboard\".
            """
            HORIZONTAL_LINES = FADE_EFFECT_HORIZONTAL_LINES
            """
            use the animation effect \"Horizontal Lines\".

            use the fade effect \"Horizontal Lines\".
            """
            HORIZONTAL_STRIPES = FADE_EFFECT_HORIZONTAL_STRIPES
            """
            use the animation effect \"Horizontal Stripes\".

            use the fade effect \"Horizontal Stripes\".
            """
            MOVE_FROM_BOTTOM = FADE_EFFECT_MOVE_FROM_BOTTOM
            """
            use the animation effect \"Move from Bottom\".

            use the fade effect \"Move from Bottom\".
            """
            MOVE_FROM_LEFT = FADE_EFFECT_MOVE_FROM_LEFT
            """
            use the animation effect \"Move from Left\".

            use the fade effect \"Move from Left\".
            """
            MOVE_FROM_LOWERLEFT = FADE_EFFECT_MOVE_FROM_LOWERLEFT
            """
            use the animation effect \"Move from Lower Left\".

            use the fade effect \"Move from Lower Left\".
            """
            MOVE_FROM_LOWERRIGHT = FADE_EFFECT_MOVE_FROM_LOWERRIGHT
            """
            use the animation effect \"Move from Lower Right\".

            use the fade effect \"Move from Lower Right\".
            """
            MOVE_FROM_RIGHT = FADE_EFFECT_MOVE_FROM_RIGHT
            """
            use the animation effect \"Move from Right\".

            use the fade effect \"Move from Right\".
            """
            MOVE_FROM_TOP = FADE_EFFECT_MOVE_FROM_TOP
            """
            use the animation effect \"Move from Top\".

            use the fade effect \"Move from Top\".
            """
            MOVE_FROM_UPPERLEFT = FADE_EFFECT_MOVE_FROM_UPPERLEFT
            """
            use the animation effect \"Move from Upper Left\".

            use the fade effect \"Move from Upper Left\".
            """
            MOVE_FROM_UPPERRIGHT = FADE_EFFECT_MOVE_FROM_UPPERRIGHT
            """
            use the animation effect \"Move from Upper Right\".

            use the fade effect \"Move from Upper Right\".
            """
            NONE = FADE_EFFECT_NONE
            """
            use no animation effects.

            use no fade effects.

            No action is performed on click.
            """
            OPEN_HORIZONTAL = FADE_EFFECT_OPEN_HORIZONTAL
            """
            use the animation effect \"Open Horizontal\".

            use the fade effect \"Open Horizontal\".
            """
            OPEN_VERTICAL = FADE_EFFECT_OPEN_VERTICAL
            """
            use the animation effect \"Open Vertical\".

            use the fade effect \"Open Vertical\".
            """
            RANDOM = FADE_EFFECT_RANDOM
            """
            use the animation effect \"Random\".

            use the fade effect \"Random\".
            """
            ROLL_FROM_BOTTOM = FADE_EFFECT_ROLL_FROM_BOTTOM
            """
            use the fade effect \"Roll from Bottom\".
            """
            ROLL_FROM_LEFT = FADE_EFFECT_ROLL_FROM_LEFT
            """
            use the fade effect \"Roll from Left\".
            """
            ROLL_FROM_RIGHT = FADE_EFFECT_ROLL_FROM_RIGHT
            """
            use the fade effect \"Roll from Right\".
            """
            ROLL_FROM_TOP = FADE_EFFECT_ROLL_FROM_TOP
            """
            use the fade effect \"Roll from Top\".
            """
            SPIRALIN_LEFT = FADE_EFFECT_SPIRALIN_LEFT
            """
            use the animation effect \"Spiral Inward Left\".

            use the fade effect \"Spiral Inward Left\".
            """
            SPIRALIN_RIGHT = FADE_EFFECT_SPIRALIN_RIGHT
            """
            use the animation effect \"Spiral Inward Right\".

            use the fade effect \"Spiral Inward Right\".
            """
            SPIRALOUT_LEFT = FADE_EFFECT_SPIRALOUT_LEFT
            """
            use the animation effect \"Spiral Outward Left\".

            use the fade effect \"Spiral Outward Left\".
            """
            SPIRALOUT_RIGHT = FADE_EFFECT_SPIRALOUT_RIGHT
            """
            use the animation effect \"Spiral Outward Right\".

            use the fade effect \"Spiral Outward Right\".
            """
            STRETCH_FROM_BOTTOM = FADE_EFFECT_STRETCH_FROM_BOTTOM
            """
            use the animation effect \"Stretch From Bottom\".

            use the fade effect \"Stretch from Bottom\".
            """
            STRETCH_FROM_LEFT = FADE_EFFECT_STRETCH_FROM_LEFT
            """
            use the animation effect \"Stretch From Left\".

            use the fade effect \"Stretch from Left\".
            """
            STRETCH_FROM_RIGHT = FADE_EFFECT_STRETCH_FROM_RIGHT
            """
            use the animation effect \"Stretch From Right\".

            use the fade effect \"Stretch from Right\".
            """
            STRETCH_FROM_TOP = FADE_EFFECT_STRETCH_FROM_TOP
            """
            use the animation effect \"Stretch From Top\".

            use the fade effect \"Stretch from Top\".
            """
            UNCOVER_TO_BOTTOM = FADE_EFFECT_UNCOVER_TO_BOTTOM
            """
            use the fade effect \"Uncover to Bottom\".
            """
            UNCOVER_TO_LEFT = FADE_EFFECT_UNCOVER_TO_LEFT
            """
            use the fade effect \"Uncover to Left\".
            """
            UNCOVER_TO_LOWERLEFT = FADE_EFFECT_UNCOVER_TO_LOWERLEFT
            """
            use the fade effect \"Uncover to Lower Left\".
            """
            UNCOVER_TO_LOWERRIGHT = FADE_EFFECT_UNCOVER_TO_LOWERRIGHT
            """
            use the fade effect \"Uncover to Lower Right\".
            """
            UNCOVER_TO_RIGHT = FADE_EFFECT_UNCOVER_TO_RIGHT
            """
            use the fade effect \"Uncover to Right\".
            """
            UNCOVER_TO_TOP = FADE_EFFECT_UNCOVER_TO_TOP
            """
            use the fade effect \"Uncover to Top\".
            """
            UNCOVER_TO_UPPERLEFT = FADE_EFFECT_UNCOVER_TO_UPPERLEFT
            """
            use the fade effect \"Uncover to Upper Left\".
            """
            UNCOVER_TO_UPPERRIGHT = FADE_EFFECT_UNCOVER_TO_UPPERRIGHT
            """
            use the fade effect \"Uncover to Upper Right\".
            """
            VERTICAL_CHECKERBOARD = FADE_EFFECT_VERTICAL_CHECKERBOARD
            """
            use the animation effect \"Vertical Checkerboard\".

            use the fade effect \"Vertical Checkerboard\".
            """
            VERTICAL_LINES = FADE_EFFECT_VERTICAL_LINES
            """
            use the animation effect \"Vertical Lines\".

            use the fade effect \"Vertical Lines\".
            """
            VERTICAL_STRIPES = FADE_EFFECT_VERTICAL_STRIPES
            """
            use the animation effect \"Vertical Stripes\".

            use the fade effect \"Vertical Stripes\".
            """
            WAVYLINE_FROM_BOTTOM = FADE_EFFECT_WAVYLINE_FROM_BOTTOM
            """
            use the animation effect \"Wavy Line from Button\".

            use the fade effect \"Wavy Line from Bottom\".
            """
            WAVYLINE_FROM_LEFT = FADE_EFFECT_WAVYLINE_FROM_LEFT
            """
            use the animation effect \"Wavy Line from Left\".

            use the fade effect \"Wavy Line from Left\".
            """
            WAVYLINE_FROM_RIGHT = FADE_EFFECT_WAVYLINE_FROM_RIGHT
            """
            use the animation effect \"Wavy Line from Right\".

            use the fade effect \"Wavy Line from Right\".
            """
            WAVYLINE_FROM_TOP = FADE_EFFECT_WAVYLINE_FROM_TOP
            """
            use the animation effect \"Wavy Line from Top\".

            use the fade effect \"Wavy Line from Top\".
            """
    else:
        # keep document generators happy
        from ...lo.presentation.fade_effect import FadeEffect as FadeEffect


__all__ = ['FadeEffect']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_key_handler import XKeyHandler as XKeyHandler_98520a93
    from .x_mouse_click_handler import XMouseClickHandler as XMouseClickHandler_edcb0d59

class XUserInputInterception(XInterface_8f010a43):
    """
    Interface to add handlers for key and mouse events.
    
    A handler is not a passive listener, it can even consume the event.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XUserInputInterception <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XUserInputInterception.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XUserInputInterception'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XUserInputInterception'

    @abstractmethod
    def addKeyHandler(self, xHandler: XKeyHandler_98520a93) -> None:
        """
        Add a new listener that is called on com.sun.star.awt.KeyEvent.
        
        Every listener is given the opportunity to consume the event, i.e. prevent the not yet called listeners from being called.
        """
        ...
    @abstractmethod
    def addMouseClickHandler(self, xHandler: XMouseClickHandler_edcb0d59) -> None:
        """
        Add a new listener that is called on com.sun.star.awt.MouseEvent.
        
        Every listener is given the opportunity to consume the event, i.e. prevent the not yet called listeners from being called.
        """
        ...
    @abstractmethod
    def removeKeyHandler(self, xHandler: XKeyHandler_98520a93) -> None:
        """
        Remove the specified listener from the list of listeners.
        """
        ...
    @abstractmethod
    def removeMouseClickHandler(self, xHandler: XMouseClickHandler_edcb0d59) -> None:
        """
        Remove the specified listener from the list of listeners.
        """
        ...

__all__ = ['XUserInputInterception']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2


class ConversionPropertyType(object):
    """
    Const Class

    specifies the property type of an entry in a conversion dictionary.
    
    **since**
    
        OOo 2.0

    See Also:
        `API ConversionPropertyType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1ConversionPropertyType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.ConversionPropertyType'
    __ooo_type_name__: str = 'const'

    NOT_DEFINED = 0
    """
    There is no property type defined or available.
    """
    OTHER = 1
    """
    Any word that does not fit into any of the other properties.
    """
    FOREIGN = 2
    """
    A word or term that is transliterated or used from a non-Chinese language.
    """
    FIRST_NAME = 3
    """
    The first name (given name) of a person.
    """
    LAST_NAME = 4
    """
    The last name (family name) of a person.
    """
    TITLE = 5
    """
    The academic or social title of a person.
    """
    STATUS = 6
    """
    The status of a situation.
    """
    PLACE_NAME = 7
    """
    The name of a location or place.
    """
    BUSINESS = 8
    """
    The description of a business.
    """
    ADJECTIVE = 9
    """
    An adjective.
    """
    IDIOM = 10
    """
    A term that is used to literally describe a circumstance.
    """
    ABBREVIATION = 11
    """
    An abbreviation.
    """
    NUMERICAL = 12
    """
    A numeric word.
    """
    NOUN = 13
    """
    A noun.
    """
    VERB = 14
    """
    A verb.
    """
    BRAND_NAME = 15
    """
    The name of a product or a company.
    """

__all__ = ['ConversionPropertyType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FilterOperator2(metaclass=UnoConstMeta, type_name="com.sun.star.sheet.FilterOperator2", name_space="com.sun.star.sheet"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.sheet.FilterOperator2``"""
        pass

    class FilterOperator2Enum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.sheet.FilterOperator2", name_space="com.sun.star.sheet"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.sheet.FilterOperator2`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.sheet import FilterOperator2 as FilterOperator2
    else:
        # keep document generators happy
        from ...lo.sheet.filter_operator2 import FilterOperator2 as FilterOperator2

    class FilterOperator2Enum(IntEnum):
        """
        Enum of Const Class FilterOperator2

        specifies the type of a single condition in a filter descriptor.
        
        This constants group extends the FilterOperator enum by additional filter operators.
        
        **since**
        
            OOo 3.2
        """
        EMPTY = FilterOperator2.EMPTY
        """
        selects empty entries.
        """
        NOT_EMPTY = FilterOperator2.NOT_EMPTY
        """
        selects non-empty entries.
        """
        EQUAL = FilterOperator2.EQUAL
        """
        value has to be equal to the specified value.
        """
        NOT_EQUAL = FilterOperator2.NOT_EQUAL
        """
        value must not be equal to the specified value.
        """
        GREATER = FilterOperator2.GREATER
        """
        value has to be greater than the specified value.
        """
        GREATER_EQUAL = FilterOperator2.GREATER_EQUAL
        """
        value has to be greater than or equal to the specified value.
        """
        LESS = FilterOperator2.LESS
        """
        value has to be less than the specified value.
        """
        LESS_EQUAL = FilterOperator2.LESS_EQUAL
        """
        value has to be less than or equal to the specified value.
        """
        TOP_VALUES = FilterOperator2.TOP_VALUES
        """
        selects a specified number of entries with the greatest values.
        """
        TOP_PERCENT = FilterOperator2.TOP_PERCENT
        """
        selects a specified percentage of entries with the greatest values.
        """
        BOTTOM_VALUES = FilterOperator2.BOTTOM_VALUES
        """
        selects a specified number of entries with the lowest values.
        """
        BOTTOM_PERCENT = FilterOperator2.BOTTOM_PERCENT
        """
        selects a specified percentage of entries with the lowest values.
        """
        CONTAINS = FilterOperator2.CONTAINS
        """
        selects contains entries.
        """
        DOES_NOT_CONTAIN = FilterOperator2.DOES_NOT_CONTAIN
        """
        selects does-not-contain entries.
        """
        BEGINS_WITH = FilterOperator2.BEGINS_WITH
        """
        selects begins-with entries.
        """
        DOES_NOT_BEGIN_WITH = FilterOperator2.DOES_NOT_BEGIN_WITH
        """
        selects does-not-begin-with entries.
        """
        ENDS_WITH = FilterOperator2.ENDS_WITH
        """
        selects ends-with entries.
        """
        DOES_NOT_END_WITH = FilterOperator2.DOES_NOT_END_WITH
        """
        selects does-not-end-with entries.
        """

__all__ = ['FilterOperator2', 'FilterOperator2Enum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.embed.actions import Actions as Actions
from ...lo.embed.aspects import Aspects as Aspects
from ...lo.embed.base_storage import BaseStorage as BaseStorage
from ...lo.embed.document_closer import DocumentCloser as DocumentCloser
from ...lo.embed.element_modes import ElementModes as ElementModes
from ...lo.embed.embed_map_units import EmbedMapUnits as EmbedMapUnits
from ...lo.embed.embed_misc import EmbedMisc as EmbedMisc
from ...lo.embed.embed_states import EmbedStates as EmbedStates
from ...lo.embed.embed_update_modes import EmbedUpdateModes as EmbedUpdateModes
from ...lo.embed.embed_verbs import EmbedVerbs as EmbedVerbs
from ...lo.embed.embedded_object_creator import EmbeddedObjectCreator as EmbeddedObjectCreator
from ...lo.embed.embedded_object_descriptor import EmbeddedObjectDescriptor as EmbeddedObjectDescriptor
from ...lo.embed.entry_init_modes import EntryInitModes as EntryInitModes
from ...lo.embed.file_system_storage import FileSystemStorage as FileSystemStorage
from ...lo.embed.file_system_storage_factory import FileSystemStorageFactory as FileSystemStorageFactory
from ...lo.embed.hatch_window_factory import HatchWindowFactory as HatchWindowFactory
from ...lo.embed.inserted_object_info import InsertedObjectInfo as InsertedObjectInfo
from ...lo.embed.instance_locker import InstanceLocker as InstanceLocker
from ...lo.embed.invalid_storage_exception import InvalidStorageException as InvalidStorageException
from ...lo.embed.linkage_misuse_exception import LinkageMisuseException as LinkageMisuseException
from ...lo.embed.msole_object_system_creator import MSOLEObjectSystemCreator as MSOLEObjectSystemCreator
from ...lo.embed.needs_running_state_exception import NeedsRunningStateException as NeedsRunningStateException
from ...lo.embed.no_visual_area_size_exception import NoVisualAreaSizeException as NoVisualAreaSizeException
from ...lo.embed.ole_embedded_object_factory import OLEEmbeddedObjectFactory as OLEEmbeddedObjectFactory
from ...lo.embed.ole_simple_storage import OLESimpleStorage as OLESimpleStorage
from ...lo.embed.o_oo_embedded_object_factory import OOoEmbeddedObjectFactory as OOoEmbeddedObjectFactory
from ...lo.embed.object_save_veto_exception import ObjectSaveVetoException as ObjectSaveVetoException
from ...lo.embed.state_change_in_progress_exception import StateChangeInProgressException as StateChangeInProgressException
from ...lo.embed.storage import Storage as Storage
from ...lo.embed.storage_factory import StorageFactory as StorageFactory
from ...lo.embed.storage_formats import StorageFormats as StorageFormats
from ...lo.embed.storage_stream import StorageStream as StorageStream
from ...lo.embed.storage_wrapped_target_exception import StorageWrappedTargetException as StorageWrappedTargetException
from ...lo.embed.unreachable_state_exception import UnreachableStateException as UnreachableStateException
from ...lo.embed.use_backup_exception import UseBackupException as UseBackupException
from ...lo.embed.verb_attributes import VerbAttributes as VerbAttributes
from ...lo.embed.verb_descriptor import VerbDescriptor as VerbDescriptor
from ...lo.embed.visual_representation import VisualRepresentation as VisualRepresentation
from ...lo.embed.wrong_state_exception import WrongStateException as WrongStateException
from ...lo.embed.x_actions_approval import XActionsApproval as XActionsApproval
from ...lo.embed.x_classified_object import XClassifiedObject as XClassifiedObject
from ...lo.embed.x_common_embed_persist import XCommonEmbedPersist as XCommonEmbedPersist
from ...lo.embed.x_component_supplier import XComponentSupplier as XComponentSupplier
from ...lo.embed.x_embed_object_clipboard_creator import XEmbedObjectClipboardCreator as XEmbedObjectClipboardCreator
from ...lo.embed.x_embed_object_creator import XEmbedObjectCreator as XEmbedObjectCreator
from ...lo.embed.x_embed_object_factory import XEmbedObjectFactory as XEmbedObjectFactory
from ...lo.embed.x_embed_persist import XEmbedPersist as XEmbedPersist
from ...lo.embed.x_embed_persist2 import XEmbedPersist2 as XEmbedPersist2
from ...lo.embed.x_embedded_client import XEmbeddedClient as XEmbeddedClient
from ...lo.embed.x_embedded_object import XEmbeddedObject as XEmbeddedObject
from ...lo.embed.x_embedded_object_creator import XEmbeddedObjectCreator as XEmbeddedObjectCreator
from ...lo.embed.x_embedded_ole_object import XEmbeddedOleObject as XEmbeddedOleObject
from ...lo.embed.x_encryption_protected_source import XEncryptionProtectedSource as XEncryptionProtectedSource
from ...lo.embed.x_encryption_protected_source2 import XEncryptionProtectedSource2 as XEncryptionProtectedSource2
from ...lo.embed.x_encryption_protected_storage import XEncryptionProtectedStorage as XEncryptionProtectedStorage
from ...lo.embed.x_extended_storage_stream import XExtendedStorageStream as XExtendedStorageStream
from ...lo.embed.x_hatch_window import XHatchWindow as XHatchWindow
from ...lo.embed.x_hatch_window_controller import XHatchWindowController as XHatchWindowController
from ...lo.embed.x_hatch_window_factory import XHatchWindowFactory as XHatchWindowFactory
from ...lo.embed.x_hierarchical_storage_access import XHierarchicalStorageAccess as XHierarchicalStorageAccess
from ...lo.embed.x_hierarchical_storage_access2 import XHierarchicalStorageAccess2 as XHierarchicalStorageAccess2
from ...lo.embed.x_inplace_client import XInplaceClient as XInplaceClient
from ...lo.embed.x_inplace_object import XInplaceObject as XInplaceObject
from ...lo.embed.x_insert_object_dialog import XInsertObjectDialog as XInsertObjectDialog
from ...lo.embed.x_link_creator import XLinkCreator as XLinkCreator
from ...lo.embed.x_link_factory import XLinkFactory as XLinkFactory
from ...lo.embed.x_linkage_support import XLinkageSupport as XLinkageSupport
from ...lo.embed.xole_simple_storage import XOLESimpleStorage as XOLESimpleStorage
from ...lo.embed.x_optimized_storage import XOptimizedStorage as XOptimizedStorage
from ...lo.embed.x_package_structure_creator import XPackageStructureCreator as XPackageStructureCreator
from ...lo.embed.x_persistance_holder import XPersistanceHolder as XPersistanceHolder
from ...lo.embed.x_relationship_access import XRelationshipAccess as XRelationshipAccess
from ...lo.embed.x_state_change_broadcaster import XStateChangeBroadcaster as XStateChangeBroadcaster
from ...lo.embed.x_state_change_listener import XStateChangeListener as XStateChangeListener
from ...lo.embed.x_storage import XStorage as XStorage
from ...lo.embed.x_storage2 import XStorage2 as XStorage2
from ...lo.embed.x_storage_raw_access import XStorageRawAccess as XStorageRawAccess
from ...lo.embed.x_transacted_object import XTransactedObject as XTransactedObject
from ...lo.embed.x_transaction_broadcaster import XTransactionBroadcaster as XTransactionBroadcaster
from ...lo.embed.x_transaction_listener import XTransactionListener as XTransactionListener
from ...lo.embed.x_transferable_supplier import XTransferableSupplier as XTransferableSupplier
from ...lo.embed.x_visual_object import XVisualObject as XVisualObject
from ...lo.embed.x_window_supplier import XWindowSupplier as XWindowSupplier



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_adjustment_listener import XAdjustmentListener as XAdjustmentListener_fdfc0e11

class XSpinValue(XInterface_8f010a43):
    """
    gives access to the value and settings of a control which is associated with a spinnable value.

    See Also:
        `API XSpinValue <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XSpinValue.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XSpinValue'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XSpinValue'

    @abstractmethod
    def addAdjustmentListener(self, listener: XAdjustmentListener_fdfc0e11) -> None:
        """
        registers an adjustment event listener.
        """
        ...
    @abstractmethod
    def getMaximum(self) -> int:
        """
        returns the currently set maximum value of the control
        """
        ...
    @abstractmethod
    def getMinimum(self) -> int:
        """
        returns the currently set minimum value of the control
        """
        ...
    @abstractmethod
    def getOrientation(self) -> int:
        """
        returns the current orientation of the control
        """
        ...
    @abstractmethod
    def getSpinIncrement(self) -> int:
        """
        returns the value by which the current value of the control should be incremented or decremented upon spinning.
        """
        ...
    @abstractmethod
    def getValue(self) -> int:
        """
        returns the current value of the control.
        """
        ...
    @abstractmethod
    def removeAdjustmentListener(self, listener: XAdjustmentListener_fdfc0e11) -> None:
        """
        unregisters an adjustment event listener.
        """
        ...
    @abstractmethod
    def setMaximum(self, maxValue: int) -> None:
        """
        sets the maximum value which can be set on the control
        """
        ...
    @abstractmethod
    def setMinimum(self, minValue: int) -> None:
        """
        sets the minimum value which can be set on the control
        """
        ...
    @abstractmethod
    def setOrientation(self, orientation: int) -> None:
        """
        controls the orientation of the control

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def setSpinIncrement(self, spinIncrement: int) -> None:
        """
        sets the value by which the current value of the control should be incremented or decremented upon spinning.
        """
        ...
    @abstractmethod
    def setValue(self, value: int) -> None:
        """
        sets the current value of the control
        """
        ...
    @abstractmethod
    def setValues(self, minValue: int, maxValue: int, currentValue: int) -> None:
        """
        sets the value and value range of the control
        """
        ...

__all__ = ['XSpinValue']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2.data
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class LabelOrigin(metaclass=UnoEnumMeta, type_name="com.sun.star.chart2.data.LabelOrigin", name_space="com.sun.star.chart2.data"):
        """Dynamically created class that represents ``com.sun.star.chart2.data.LabelOrigin`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.chart2.data.LabelOrigin import COLUMN as LABEL_ORIGIN_COLUMN
        from com.sun.star.chart2.data.LabelOrigin import LONG_SIDE as LABEL_ORIGIN_LONG_SIDE
        from com.sun.star.chart2.data.LabelOrigin import ROW as LABEL_ORIGIN_ROW
        from com.sun.star.chart2.data.LabelOrigin import SHORT_SIDE as LABEL_ORIGIN_SHORT_SIDE

        class LabelOrigin(uno.Enum):
            """
            Enum Class


            See Also:
                `API LabelOrigin <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html#a2afe9ba95ad4b3631057b40391bed0aa>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.chart2.data.LabelOrigin', value)

            __ooo_ns__: str = 'com.sun.star.chart2.data'
            __ooo_full_ns__: str = 'com.sun.star.chart2.data.LabelOrigin'
            __ooo_type_name__: str = 'enum'

            COLUMN = LABEL_ORIGIN_COLUMN
            """
            Uses the column name for label generation.

            A spreadsheet range A1:A6 could, e.g., result in \"Column A\".

            If a range consists of more than one column the result of label generation may be empty. Of course, it could also succeed with a string like \"Columns A to B\".
            """
            LONG_SIDE = LABEL_ORIGIN_LONG_SIDE
            """
            This is exactly the opposite of SHORT_SIDE.

            I.e., if SHORT_SIDE has the same effect as ROW, LONG_SIDE will have the same effect as COLUMN and the other way round.
            """
            ROW = LABEL_ORIGIN_ROW
            """
            Uses the column name for label generation.

            A spreadsheet range A2:D2 could, e.g., result in \"Row 2\".

            If a range consists of more than one row the result of label generation may be empty. Of course, it could also succeed with a string like \"Rows 1-3\".
            """
            SHORT_SIDE = LABEL_ORIGIN_SHORT_SIDE
            """
            If a range spans a single row over more than one column, this parameter has the same effect as ROW.

            If the range spans a single column over more than one row, this is the same as COLUMN.

            In case of a range spanning more than one column and row, the shorter range of both should be used (e.g. a spreadsheet range A1:B10 should treat columns as short side).

            In case of a rectangular range, or a range that is composed of more than one contiguous sub-regions, the short side cannot be determined, thus XDataSequence.generateLabel() will return an empty sequence.
            """
    else:
        # keep document generators happy
        from ....lo.chart2.data.label_origin import LabelOrigin as LabelOrigin


__all__ = ['LabelOrigin']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from ..lang.event_object import EventObject as EventObject_a3d70b03

class XTransactionListener(XEventListener_c7230c4a):
    """
    makes it possible to receive events when a transacted object is committed or reverted.

    See Also:
        `API XTransactionListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1embed_1_1XTransactionListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.XTransactionListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.embed.XTransactionListener'

    @abstractmethod
    def commited(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is called after the object is committed.
        """
        ...
    @abstractmethod
    def preCommit(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is called just before the object is committed.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def preRevert(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is called just before the object is reverted.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
        ...
    @abstractmethod
    def reverted(self, aEvent: EventObject_a3d70b03) -> None:
        """
        is called after the object is reverted.
        """
        ...

__all__ = ['XTransactionListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ....dyn.frame.status.clipboard_formats import ClipboardFormats as ClipboardFormats
with suppress(ImportError):
    from ....dyn.frame.status.font_height import FontHeight as FontHeight
with suppress(ImportError):
    from ....dyn.frame.status.item_state import ItemState as ItemState
with suppress(ImportError):
    from ....dyn.frame.status.item_state import ItemStateEnum as ItemStateEnum
with suppress(ImportError):
    from ....dyn.frame.status.item_status import ItemStatus as ItemStatus
with suppress(ImportError):
    from ....dyn.frame.status.left_right_margin import LeftRightMargin as LeftRightMargin
with suppress(ImportError):
    from ....dyn.frame.status.left_right_margin_scale import LeftRightMarginScale as LeftRightMarginScale
with suppress(ImportError):
    from ....dyn.frame.status.template import Template as Template
with suppress(ImportError):
    from ....dyn.frame.status.upper_lower_margin import UpperLowerMargin as UpperLowerMargin
with suppress(ImportError):
    from ....dyn.frame.status.upper_lower_margin_scale import UpperLowerMarginScale as UpperLowerMarginScale
with suppress(ImportError):
    from ....dyn.frame.status.verb import Verb as Verb
with suppress(ImportError):
    from ....dyn.frame.status.visibility import Visibility as Visibility



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .mouse_event import MouseEvent as MouseEvent_8f430a5f

class XMouseMotionListener(XEventListener_c7230c4a):
    """
    makes it possible to receive mouse motion events on a window.

    See Also:
        `API XMouseMotionListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XMouseMotionListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XMouseMotionListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XMouseMotionListener'

    @abstractmethod
    def mouseDragged(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when a mouse button is pressed on a window and then dragged.
        
        Mouse drag events will continue to be delivered to the window where the first event originated until the mouse button is released (regardless of whether the mouse position is within the bounds of the window).
        """
        ...
    @abstractmethod
    def mouseMoved(self, e: MouseEvent_8f430a5f) -> None:
        """
        is invoked when the mouse pointer has been moved on a window (with no buttons down).
        """
        ...

__all__ = ['XMouseMotionListener']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_axis_supplier import XAxisSupplier as XAxisSupplier_c81b0c5b
from .x_diagram import XDiagram as XDiagram_8e1e0a27
from .x_diagram_positioning import XDiagramPositioning as XDiagramPositioning_18f60eba
from .x_second_axis_title_supplier import XSecondAxisTitleSupplier as XSecondAxisTitleSupplier_680a10b9
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from com.sun.star.chart.ChartDataRowSource import ChartDataRowSourceProto

class Diagram(UserDefinedAttributesSupplier_9fbe1222, XPropertySet_bc180bfa, XAxisSupplier_c81b0c5b, XDiagram_8e1e0a27, XDiagramPositioning_18f60eba, XSecondAxisTitleSupplier_680a10b9):
    """
    Service Class

    the base service for the diagram of the chart document.
    
    The diagram is the object that contains the actual plot.
    
    Different Diagram Types, e.g., PieDiagram or LineDiagram, can be instantiated by the com.sun.star.lang.XMultiServiceFactory of the XChartDocument.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API Diagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1Diagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.Diagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AutomaticPosition(self) -> bool:
        """
        If this property is TRUE the position is calculated by the application automatically.
        
        Setting this property to false will have no effect. Instead use the interface com.sun.star.drawing.XShape to set a concrete position (note com.sun.star.chart.XDiagram is derived from com.sun.star.drawing.XShape).
        """
        ...

    @abstractproperty
    def AutomaticSize(self) -> bool:
        """
        If this property is TRUE the size is calculated by the application automatically.
        
        Setting this property to false will have no effect. Instead use the interface com.sun.star.drawing.XShape to set a concrete size (note com.sun.star.chart.XDiagram is derived from com.sun.star.drawing.XShape).
        """
        ...

    @abstractproperty
    def DataCaption(self) -> int:
        """
        specifies how the caption of data points is displayed.
        """
        ...

    @abstractproperty
    def DataRowSource(self) -> ChartDataRowSourceProto:
        """
        determines if the data for a data row is contained in the columns or in the rows of the data array.
        """
        ...

    @abstractproperty
    def MissingValueTreatment(self) -> int:
        """
        specifies how empty or invalid cells in the provided data should be handled when displayed
        """
        ...


__all__ = ['Diagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
from .data_importer import DataImporter as DataImporter_b39c1242

class LocalDataImporter(DataImporter_b39c1242):
    """
    Service Class

    allows importing data from a local configuration data repository or file into any Backend.
    
    Data to be imported can be a single layer either from a full local configuration database or from a particular OOR Update XML file.
    
    Data is imported into the DefaultBackend.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API LocalDataImporter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1LocalDataImporter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.LocalDataImporter'
    __ooo_type_name__: str = 'service'


__all__ = ['LocalDataImporter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from abc import abstractproperty, ABC

class RotationDescriptor(ABC):
    """
    Service Class

    This abstract service specifies the general characteristics of an optional rotation and shearing for a Shape.
    
    This service is deprecated, instead please use the Transformation property of the service Shape.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API RotationDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1RotationDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.RotationDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def RotateAngle(self) -> int:
        """
        This is the angle for rotation of this Shape.
        
        The shape is rotated counter-clockwise around the center of the bounding box.
        
        This property contains an error, the rotation angle is mathematically inverted when You take into account that the Y-Axis of the coordinate system is pointing down. Please use the Transformation property of the service Shape instead.
        """
        ...

    @abstractproperty
    def ShearAngle(self) -> int:
        """
        This is the amount of shearing for this Shape.
        
        The shape is sheared counter-clockwise around the center of the bounding box
        """
        ...


__all__ = ['RotationDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_transferable import XTransferable as XTransferable_2d800f38
if typing.TYPE_CHECKING:
    from .data_flavor import DataFlavor as DataFlavor_ffd30deb

class XTransferable2(XTransferable_2d800f38):
    """
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API XTransferable2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1XTransferable2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.XTransferable2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.XTransferable2'

    @abstractmethod
    def getTransferData2(self, aFlavor: DataFlavor_ffd30deb, aDestShellID: str) -> object:
        """
        This is equivalent of getTransferData of XTransferable, but takes an additional parameter that specifies the destination document type.

        Raises:
            UnsupportedFlavorException: ``UnsupportedFlavorException``
            com.sun.star.io.IOException: ``IOException``
        """
        ...
    @abstractmethod
    def isComplex(self) -> bool:
        """
        Returns true if the selection contains embedded objects or is a large text blob.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

__all__ = ['XTransferable2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.bridge.oleautomation
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class PropertyPutArgument(object):
    """
    Struct Class

    contains a value that is used as argument in a \"property put&quot operation on an Automation object.
    
    If an Automation object is converted into a UNO object by a scripting bridge, such as com.sun.star.bridge.oleautomation.BridgeSupplier, then it is accessed through the com.sun.star.script.XInvocation interface. The methods com.sun.star.script.XInvocation.setValue() and com.sun.star.script.XInvocation.getValue() are used to access properties which do not have additional arguments. To access a property with additional arguments, the method com.sun.star.script.XInvocation.invoke() has to be used. The method implementation must decide, if the property is to be written or read so it can perform the proper operation on the Automation object. To make this decision, the caller has to provide the information if the current call is intended to be a write or read operation. This is done by providing either instances of PropertyPutArgument or PropertyGetArgument as arguments to com.sun.star.script.XInvocation.Invoke.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API PropertyPutArgument <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1PropertyPutArgument.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.bridge.oleautomation'
    __ooo_full_ns__: str = 'com.sun.star.bridge.oleautomation.PropertyPutArgument'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.bridge.oleautomation.PropertyPutArgument'
    """Literal Constant ``com.sun.star.bridge.oleautomation.PropertyPutArgument``"""

    def __init__(self, Value: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            Value (object, optional): Value value.
        """
        super().__init__()

        if isinstance(Value, PropertyPutArgument):
            oth: PropertyPutArgument = Value
            self.Value = oth.Value
            return

        kargs = {
            "Value": Value,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._value = kwargs["Value"]


    @property
    def Value(self) -> object:
        """
        contains the actual argument.
        """
        return self._value

    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value


__all__ = ['PropertyPutArgument']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2


class DictionaryListEventFlags(object):
    """
    Const Class

    constants representing a single dictionary-list event.
    
    These flags define the possible types for a dictionary-list event.

    See Also:
        `API DictionaryListEventFlags <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1linguistic2_1_1DictionaryListEventFlags.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.DictionaryListEventFlags'
    __ooo_type_name__: str = 'const'

    ADD_POS_ENTRY = 1
    """
    A positive entry was added to a dictionary from the dictionary list.
    """
    DEL_POS_ENTRY = 2
    """
    A positive entry was deleted from a dictionary of the dictionary-list or a dictionary with positive entries was cleared.
    """
    ADD_NEG_ENTRY = 4
    """
    A negative entry was added to a dictionary from the dictionary-list.
    """
    DEL_NEG_ENTRY = 8
    """
    A negative entry was deleted from a dictionary of the dictionary-list or a dictionary with negative entries was cleared.
    """
    ACTIVATE_POS_DIC = 16
    """
    A dictionary with positive entries was activated or has changed its language.
    """
    DEACTIVATE_POS_DIC = 32
    """
    A dictionary with positive entries was deactivated or has changed its language.
    """
    ACTIVATE_NEG_DIC = 64
    """
    A dictionary with negative entries was activated or has changed its language.
    """
    DEACTIVATE_NEG_DIC = 128
    """
    A dictionary with negative entries was deactivated or has changed its language.
    """

__all__ = ['DictionaryListEventFlags']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.task
from __future__ import annotations
from abc import abstractmethod
from .x_interaction_password import XInteractionPassword as XInteractionPassword_1ba00ee6

class XInteractionPassword2(XInteractionPassword_1ba00ee6):
    """
    A continuation to get a password from interaction helper, extends XInteractionPassword with possibility to provide password to modify.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XInteractionPassword2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1task_1_1XInteractionPassword2.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.task'
    __ooo_full_ns__: str = 'com.sun.star.task.XInteractionPassword2'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.task.XInteractionPassword2'

    @abstractmethod
    def getPasswordToModify(self) -> str:
        """
        gets \"password to modify\" from the continuation.
        """
        ...
    @abstractmethod
    def getRecommendReadOnly(self) -> bool:
        """
        gets \"recommend readonly\" from the continuation.
        
        It specifies whether the document should be loaded readonly per default.
        """
        ...
    @abstractmethod
    def setPasswordToModify(self, aPasswd: str) -> None:
        """
        stores \"password to modify\" to the continuation.
        """
        ...
    @abstractmethod
    def setRecommendReadOnly(self, bReadOnly: bool) -> None:
        """
        stores \"recommend readonly\" to the continuation.
        
        It specifies whether the document should be loaded readonly per default.
        """
        ...

__all__ = ['XInteractionPassword2']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from .x_embedded_scripts import XEmbeddedScripts as XEmbeddedScripts_1ab50eb1

class XScriptInvocationContext(ABC):
    """
    indicates support for executing scripts contained in a, possibly foreign, document.
    
    If the component implementing it is a document, which supports embedding scripts into itself, then ScriptContainer refers to the document itself. Implementing this interface is unnecessary then, instead the document should simply implement XEmbeddedScripts directly.
    
    If the interface is implemented by a document which does not itself support embedding scripts into it, but which is associated unambiguously with a document which does, then this other document is denoted by ScriptContainer.
    
    If the interface is implemented by a controller, then ScriptContainer refers to the document which supports embedding scripts, and which is unambiguously associated with the controller. This must not necessarily be the model returned by com.sun.star.frame.XController.getModel().
    
    **since**
    
        OOo 2.4

    See Also:
        `API XScriptInvocationContext <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XScriptInvocationContext.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XScriptInvocationContext'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XScriptInvocationContext'

    @abstractproperty
    def ScriptContainer(self) -> XEmbeddedScripts_1ab50eb1:
        """
        denotes the document which contains the scripts which are to be invoked from the component implementing the XScriptInvocationContext interface.
        """
        ...


__all__ = ['XScriptInvocationContext']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.io
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_data_input_stream import XDataInputStream as XDataInputStream_c56e0c2e
if typing.TYPE_CHECKING:
    from .x_persist_object import XPersistObject as XPersistObject_af2f0b79

class XObjectInputStream(XDataInputStream_c56e0c2e):
    """
    reads XPersistObject implementations from a stream

    See Also:
        `API XObjectInputStream <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1io_1_1XObjectInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.XObjectInputStream'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.io.XObjectInputStream'

    @abstractmethod
    def readObject(self) -> XPersistObject_af2f0b79:
        """
        reads an object from the stream.
        
        In general, it reads the service name, instantiates the object and calls read on the XPersistObject interface with itself as argument.

        Raises:
            com.sun.star.io.IOException: ``IOException``
        """
        ...

__all__ = ['XObjectInputStream']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractmethod
from .xui_configuration import XUIConfiguration as XUIConfiguration_c4eb0c34
from .xui_configuration_persistence import XUIConfigurationPersistence as XUIConfigurationPersistence_661010b9
from .xui_configuration_storage import XUIConfigurationStorage as XUIConfigurationStorage_25ac0f09
if typing.TYPE_CHECKING:
    from ..awt.key_event import KeyEvent as KeyEvent_7a78097f

class XAcceleratorConfiguration(XUIConfiguration_c4eb0c34, XUIConfigurationPersistence_661010b9, XUIConfigurationStorage_25ac0f09):
    """
    provides read/write access to an accelerator configuration set.
    
    Such configuration set base on:
    
    Note further:All changes you made on this configuration access modify the configuration set inside memory only. You have to use the com.sun.star.util.XFlushable interface (which must be available at the same implementation object too), to make it persistent.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XAcceleratorConfiguration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1XAcceleratorConfiguration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.XAcceleratorConfiguration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.ui.XAcceleratorConfiguration'

    @abstractmethod
    def getAllKeyEvents(self) -> typing.Tuple[KeyEvent_7a78097f, ...]:
        """
        return the list of all key events, which are available at this configuration set.
        
        The key events are the \"primary keys\" of this configuration sets. Means: Commands are registered for key events.
        
        Such key event can be mapped to its bound command, using the method getCommandForKeyEvent().
        """
        ...
    @abstractmethod
    def getCommandByKeyEvent(self, aKeyEvent: KeyEvent_7a78097f) -> str:
        """
        return the registered command for the specified key event.
        
        This function can be used to:

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def getKeyEventsByCommand(self, sCommand: str) -> typing.Tuple[KeyEvent_7a78097f, ...]:
        """
        optimized access to the relation \"command-key\" instead of \"key-command\" which is provided normally by this interface.
        
        It can be used to implement collision handling, if more than one key event match to the same command. The returned list contains all possible key events - and the outside code can select a possible one. Of course - mostly this list will contain only one key event ...

        Raises:
            : ````
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def getPreferredKeyEventsForCommandList(self, lCommandList: typing.Tuple[str, ...]) -> typing.Tuple[object, ...]:
        """
        optimized function to map a list of commands to a corresponding list of key events.
        
        It provides a fast mapping, which is e.g. needed by a menu or toolbar implementation. E.g. a sub menu is described by a list of commands - and the implementation of the menu must show the corresponding shortcuts. Iteration over all items of this configuration set can be very expensive.
        
        Instead to the method getKeyEventsForCommand() the returned list contains only one(!) key event bound to one(!) requested command. If more than one key event is bound to a command - a selection is done inside this method. This internal selection can't be influenced from outside.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def removeCommandFromAllKeyEvents(self, sCommand: str) -> None:
        """
        search for a key-command-binding inside this configuration set, where the specified command is used.
        
        If such binding could be located, the command will be removed from it. If as result of that the key binding will be empty, if will be removed too.
        
        This is an optimized method, which can perform removing of commands from this configuration set. Because normally Commands are \"foreign keys\" and key identifier the \"primary keys\" - it needs some work to remove all commands outside this container ...

        Raises:
            : ````
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def removeKeyEvent(self, aKeyEvent: KeyEvent_7a78097f) -> None:
        """
        remove a key-command-binding from this configuration set.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def setKeyEvent(self, aKeyEvent: KeyEvent_7a78097f, sCommand: str) -> None:
        """
        modify or create a key - command - binding.
        
        If the specified key event does not already exists inside this configuration access, it will be created and the command will be registered for it.
        
        If the specified key event already exists, its command will be overwritten with the new command. There is no warning nor any error about that! The outside code has to use the method getCommandForKeyEvent() to check for possible collisions.
        
        Note: This method can't be used to remove entities from the configuration set. Empty parameters will result into an exception! Use the method removeKeyEvent() instead.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XAcceleratorConfiguration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.accessibility.accessible import Accessible as Accessible
with suppress(ImportError):
    from ...dyn.accessibility.accessible_context import AccessibleContext as AccessibleContext
with suppress(ImportError):
    from ...dyn.accessibility.accessible_event_id import AccessibleEventId as AccessibleEventId
with suppress(ImportError):
    from ...dyn.accessibility.accessible_event_id import AccessibleEventIdEnum as AccessibleEventIdEnum
with suppress(ImportError):
    from ...dyn.accessibility.accessible_event_object import AccessibleEventObject as AccessibleEventObject
with suppress(ImportError):
    from ...dyn.accessibility.accessible_relation import AccessibleRelation as AccessibleRelation
with suppress(ImportError):
    from ...dyn.accessibility.accessible_relation_type import AccessibleRelationType as AccessibleRelationType
with suppress(ImportError):
    from ...dyn.accessibility.accessible_relation_type import AccessibleRelationTypeEnum as AccessibleRelationTypeEnum
with suppress(ImportError):
    from ...dyn.accessibility.accessible_role import AccessibleRole as AccessibleRole
with suppress(ImportError):
    from ...dyn.accessibility.accessible_role import AccessibleRoleEnum as AccessibleRoleEnum
with suppress(ImportError):
    from ...dyn.accessibility.accessible_scroll_type import AccessibleScrollType as AccessibleScrollType
with suppress(ImportError):
    from ...dyn.accessibility.accessible_state_type import AccessibleStateType as AccessibleStateType
with suppress(ImportError):
    from ...dyn.accessibility.accessible_state_type import AccessibleStateTypeEnum as AccessibleStateTypeEnum
with suppress(ImportError):
    from ...dyn.accessibility.accessible_table_model_change import AccessibleTableModelChange as AccessibleTableModelChange
with suppress(ImportError):
    from ...dyn.accessibility.accessible_table_model_change_type import AccessibleTableModelChangeType as AccessibleTableModelChangeType
with suppress(ImportError):
    from ...dyn.accessibility.accessible_table_model_change_type import AccessibleTableModelChangeTypeEnum as AccessibleTableModelChangeTypeEnum
with suppress(ImportError):
    from ...dyn.accessibility.accessible_text_type import AccessibleTextType as AccessibleTextType
with suppress(ImportError):
    from ...dyn.accessibility.accessible_text_type import AccessibleTextTypeEnum as AccessibleTextTypeEnum
with suppress(ImportError):
    from ...dyn.accessibility.illegal_accessible_component_state_exception import IllegalAccessibleComponentStateException as IllegalAccessibleComponentStateException
with suppress(ImportError):
    from ...dyn.accessibility.msaa_service import MSAAService as MSAAService
with suppress(ImportError):
    from ...dyn.accessibility.text_segment import TextSegment as TextSegment
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible import XAccessible as XAccessible
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_action import XAccessibleAction as XAccessibleAction
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_component import XAccessibleComponent as XAccessibleComponent
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_context import XAccessibleContext as XAccessibleContext
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_context2 import XAccessibleContext2 as XAccessibleContext2
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_context3 import XAccessibleContext3 as XAccessibleContext3
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_editable_text import XAccessibleEditableText as XAccessibleEditableText
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_event_broadcaster import XAccessibleEventBroadcaster as XAccessibleEventBroadcaster
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_event_listener import XAccessibleEventListener as XAccessibleEventListener
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_extended_attributes import XAccessibleExtendedAttributes as XAccessibleExtendedAttributes
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_extended_component import XAccessibleExtendedComponent as XAccessibleExtendedComponent
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_group_position import XAccessibleGroupPosition as XAccessibleGroupPosition
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_hyperlink import XAccessibleHyperlink as XAccessibleHyperlink
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_hypertext import XAccessibleHypertext as XAccessibleHypertext
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_image import XAccessibleImage as XAccessibleImage
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_key_binding import XAccessibleKeyBinding as XAccessibleKeyBinding
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_multi_line_text import XAccessibleMultiLineText as XAccessibleMultiLineText
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_relation_set import XAccessibleRelationSet as XAccessibleRelationSet
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_selection import XAccessibleSelection as XAccessibleSelection
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_state_set import XAccessibleStateSet as XAccessibleStateSet
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_table import XAccessibleTable as XAccessibleTable
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_table_selection import XAccessibleTableSelection as XAccessibleTableSelection
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_text import XAccessibleText as XAccessibleText
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_text_attributes import XAccessibleTextAttributes as XAccessibleTextAttributes
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_text_markup import XAccessibleTextMarkup as XAccessibleTextMarkup
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_text_selection import XAccessibleTextSelection as XAccessibleTextSelection
with suppress(ImportError):
    from ...dyn.accessibility.x_accessible_value import XAccessibleValue as XAccessibleValue
with suppress(ImportError):
    from ...dyn.accessibility.xmsaa_service import XMSAAService as XMSAAService



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class GeneralFunction(metaclass=UnoEnumMeta, type_name="com.sun.star.sheet.GeneralFunction", name_space="com.sun.star.sheet"):
        """Dynamically created class that represents ``com.sun.star.sheet.GeneralFunction`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.sheet.GeneralFunction import AUTO as GENERAL_FUNCTION_AUTO
        from com.sun.star.sheet.GeneralFunction import AVERAGE as GENERAL_FUNCTION_AVERAGE
        from com.sun.star.sheet.GeneralFunction import COUNT as GENERAL_FUNCTION_COUNT
        from com.sun.star.sheet.GeneralFunction import COUNTNUMS as GENERAL_FUNCTION_COUNTNUMS
        from com.sun.star.sheet.GeneralFunction import MAX as GENERAL_FUNCTION_MAX
        from com.sun.star.sheet.GeneralFunction import MIN as GENERAL_FUNCTION_MIN
        from com.sun.star.sheet.GeneralFunction import NONE as GENERAL_FUNCTION_NONE
        from com.sun.star.sheet.GeneralFunction import PRODUCT as GENERAL_FUNCTION_PRODUCT
        from com.sun.star.sheet.GeneralFunction import STDEV as GENERAL_FUNCTION_STDEV
        from com.sun.star.sheet.GeneralFunction import STDEVP as GENERAL_FUNCTION_STDEVP
        from com.sun.star.sheet.GeneralFunction import SUM as GENERAL_FUNCTION_SUM
        from com.sun.star.sheet.GeneralFunction import VAR as GENERAL_FUNCTION_VAR
        from com.sun.star.sheet.GeneralFunction import VARP as GENERAL_FUNCTION_VARP

        class GeneralFunction(uno.Enum):
            """
            Enum Class


            See Also:
                `API GeneralFunction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758d>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.sheet.GeneralFunction', value)

            __ooo_ns__: str = 'com.sun.star.sheet'
            __ooo_full_ns__: str = 'com.sun.star.sheet.GeneralFunction'
            __ooo_type_name__: str = 'enum'

            AUTO = GENERAL_FUNCTION_AUTO
            """
            specifies the use of a user-defined list.

            function is determined automatically.
            """
            AVERAGE = GENERAL_FUNCTION_AVERAGE
            """
            average of all numerical values is calculated.
            """
            COUNT = GENERAL_FUNCTION_COUNT
            """
            all values, including non-numerical values, are counted.
            """
            COUNTNUMS = GENERAL_FUNCTION_COUNTNUMS
            """
            numerical values are counted.
            """
            MAX = GENERAL_FUNCTION_MAX
            """
            maximum value of all numerical values is calculated.
            """
            MIN = GENERAL_FUNCTION_MIN
            """
            minimum value of all numerical values is calculated.
            """
            NONE = GENERAL_FUNCTION_NONE
            """
            no cells are moved.

            sheet is not linked.

            new values are used without changes.

            nothing is calculated.

            nothing is imported.

            no condition is specified.
            """
            PRODUCT = GENERAL_FUNCTION_PRODUCT
            """
            product of all numerical values is calculated.
            """
            STDEV = GENERAL_FUNCTION_STDEV
            """
            standard deviation is calculated based on a sample.
            """
            STDEVP = GENERAL_FUNCTION_STDEVP
            """
            standard deviation is calculated based on the entire population.
            """
            SUM = GENERAL_FUNCTION_SUM
            """
            sum of all numerical values is calculated.
            """
            VAR = GENERAL_FUNCTION_VAR
            """
            variance is calculated based on a sample.
            """
            VARP = GENERAL_FUNCTION_VARP
            """
            variance is calculated based on the entire population.
            """
    else:
        # keep document generators happy
        from ...lo.sheet.general_function import GeneralFunction as GeneralFunction


__all__ = ['GeneralFunction']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.style
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class ParagraphAdjust(metaclass=UnoEnumMeta, type_name="com.sun.star.style.ParagraphAdjust", name_space="com.sun.star.style"):
        """Dynamically created class that represents ``com.sun.star.style.ParagraphAdjust`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.style.ParagraphAdjust import BLOCK as PARAGRAPH_ADJUST_BLOCK
        from com.sun.star.style.ParagraphAdjust import CENTER as PARAGRAPH_ADJUST_CENTER
        from com.sun.star.style.ParagraphAdjust import LEFT as PARAGRAPH_ADJUST_LEFT
        from com.sun.star.style.ParagraphAdjust import RIGHT as PARAGRAPH_ADJUST_RIGHT
        from com.sun.star.style.ParagraphAdjust import STRETCH as PARAGRAPH_ADJUST_STRETCH

        class ParagraphAdjust(uno.Enum):
            """
            Enum Class


            See Also:
                `API ParagraphAdjust <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1style.html#ab9b2806f97ec4c3b5d4e2d92084948f1>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.style.ParagraphAdjust', value)

            __ooo_ns__: str = 'com.sun.star.style'
            __ooo_full_ns__: str = 'com.sun.star.style.ParagraphAdjust'
            __ooo_type_name__: str = 'enum'

            BLOCK = PARAGRAPH_ADJUST_BLOCK
            """
            adjusted to both borders / stretched, except for last line
            """
            CENTER = PARAGRAPH_ADJUST_CENTER
            """
            set the horizontal alignment to the center between the margins from the container object

            The text range is centered between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the center
            """
            LEFT = PARAGRAPH_ADJUST_LEFT
            """
            set the horizontal alignment to the left margin from the container object

            The text range is left-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the left border

            The page style is only used for left pages.
            """
            RIGHT = PARAGRAPH_ADJUST_RIGHT
            """
            set the horizontal alignment to the right margin from the container object

            The text range is right-aligned between the previous tabulator (or the left border, if none) and this tabulator.

            adjusted to the right border

            The page style is only used for right pages.
            """
            STRETCH = PARAGRAPH_ADJUST_STRETCH
            """
            adjusted to both borders / stretched, including last line
            """
    else:
        # keep document generators happy
        from ...lo.style.paragraph_adjust import ParagraphAdjust as ParagraphAdjust


__all__ = ['ParagraphAdjust']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart2.data
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.chart2.data.LabelOrigin import LabelOriginProto

class LabelOrigin(Enum):
    """
    Enum Class


    See Also:
        `API LabelOrigin <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart2_1_1data.html#a2afe9ba95ad4b3631057b40391bed0aa>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2.data'
    __ooo_full_ns__: str = 'com.sun.star.chart2.data.LabelOrigin'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.chart2.data.LabelOrigin'

    COLUMN = cast("LabelOriginProto", 'COLUMN')
    """
    Uses the column name for label generation.
    
    A spreadsheet range A1:A6 could, e.g., result in \"Column A\".
    
    If a range consists of more than one column the result of label generation may be empty. Of course, it could also succeed with a string like \"Columns A to B\".
    """
    LONG_SIDE = cast("LabelOriginProto", 'LONG_SIDE')
    """
    This is exactly the opposite of SHORT_SIDE.
    
    I.e., if SHORT_SIDE has the same effect as ROW, LONG_SIDE will have the same effect as COLUMN and the other way round.
    """
    ROW = cast("LabelOriginProto", 'ROW')
    """
    Uses the column name for label generation.
    
    A spreadsheet range A2:D2 could, e.g., result in \"Row 2\".
    
    If a range consists of more than one row the result of label generation may be empty. Of course, it could also succeed with a string like \"Rows 1-3\".
    """
    SHORT_SIDE = cast("LabelOriginProto", 'SHORT_SIDE')
    """
    If a range spans a single row over more than one column, this parameter has the same effect as ROW.
    
    If the range spans a single column over more than one row, this is the same as COLUMN.
    
    In case of a range spanning more than one column and row, the shorter range of both should be used (e.g. a spreadsheet range A1:B10 should treat columns as short side).
    
    In case of a rectangular range, or a range that is composed of more than one contiguous sub-regions, the short side cannot be determined, thus XDataSequence.generateLabel() will return an empty sequence.
    """

__all__ = ['LabelOrigin']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class Layer(XPropertySet_bc180bfa):
    """
    Service Class

    A layer is an entity inside a document which contains shapes.
    
    There could be zero or more Shapes attached to such a layer.
    
    The properties of a Layer instance affect all Shapes attached to the Layer.

    See Also:
        `API Layer <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1Layer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.Layer'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsLocked(self) -> bool:
        """
        If a Layer is locked, the objects in this Layer cannot be edited in the user interface.
        """
        ...

    @abstractproperty
    def IsPrintable(self) -> bool:
        """
        If a Layer is not printable, the objects in this Layer are not printed.
        """
        ...

    @abstractproperty
    def IsVisible(self) -> bool:
        """
        If a Layer is not visible, the objects in this Layer are not shown in the user interface.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        The name of a Layer is used to identify the Layer in the user interface.
        """
        ...


__all__ = ['Layer']

